//
// HostDatabaseMapper.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Data;
using System.Collections.Generic;
using MySql.Data;
using MySql.Data.MySqlClient;
using Ntp.Analyzer.Objects;

namespace Ntp.Analyzer.Data.Mapper
{
	/// <summary>
	/// ORM mapper for table host.
	/// </summary>
	public sealed class HostDatabaseMapper : DatabaseMapper<Host>
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="Ntp.Analyzer.Data.Mapper.HostDatabaseMapper"/> class.
		/// </summary>
		internal HostDatabaseMapper ()
		{
		}

		protected override bool UseCache {
			get { return true; }
		}

		protected override void Insert (Host item)
		{
			Open ();
			
			Command.CommandText = 
				"INSERT INTO host(name, ip, orgId) VALUES(@name, @ip, @orgId);" +
				"SELECT LAST_INSERT_ID();";
			Command.Prepare ();
           
			Command.Parameters.AddWithValue ("@name", item.Name);
			Command.Parameters.AddWithValue ("@ip", item.Ip);
			Command.Parameters.AddWithValue ("@orgId", item.OrgId);

			object idObject = Command.ExecuteScalar ();
			item.SetId (Convert.ToInt32 (idObject));
		}

		protected override void Update (Host item)
		{
			Open ();
			
			Command.CommandText = "UPDATE host SET name = @name, ip=@ip, orgId=@orgId WHERE id=@id";
			Command.Prepare ();
           
			Command.Parameters.AddWithValue ("@name", item.Name);
			Command.Parameters.AddWithValue ("@ip", item.Ip);
			Command.Parameters.AddWithValue ("@orgId", item.OrgId);
			Command.Parameters.AddWithValue ("@id", item.Id);
			Command.ExecuteScalar ();
		}

		/// <summary>
		/// Read all data from table in a sequential manner.
		/// </summary>
		/// <returns>The enumerator.</returns>
		public override IEnumerator<Host> GetEnumerator ()
		{
			if (HasContent) {
				foreach (Host host in Content)
					yield return host;
			
				yield break;
			}
			
			Open ();
			Command.CommandText = "SELECT id, name, ip, orgId FROM host;";
			MySqlDataReader reader = Command.ExecuteReader ();

			while (reader.Read()) {
				int id = Convert.ToInt32 (reader ["id"]);
				string name = reader ["name"].ToString ();
				string ip = reader ["ip"].ToString ();
				int orgId = Convert.ToInt32 (reader ["orgId"]);
				
				Host host = new Host (id, name, ip, orgId);
				AddItem (host);
				
				yield return host;
			}
			
			Close ();
		}
	}
}
