//
// NtpPacketMapper.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Net;
using Ntp.Analyzer.Objects.Packet;

namespace Ntp.Analyzer.Data.Mapper
{
	public class NtpPacketMapper : DatabaseMapper<NtpPacket>
	{
		public NtpPacketMapper ()
		{
		}

		protected override bool UseCache {
			get { return false; }
		}

		protected override void Insert (NtpPacket item)
		{
			Open ();
			
			Command.CommandText = 
				"INSERT INTO ntpPacket(time, sourceIp, sourcePort, destinationIp, destinationPort, type, strat, poll) " +
				" VALUES( ?time, ?sourceIp, ?sourcePort, ?destinationIp, ?destinationPort, ?type, ?strat, ?poll);" +
				"SELECT LAST_INSERT_ID();";
			Command.Prepare ();
           
			Command.Parameters.AddWithValue ("?time", item.Time);
			Command.Parameters.AddWithValue ("?sourceIp", item.Source.Address.ToString ());
			Command.Parameters.AddWithValue ("?sourcePort", item.Source.Port.ToString ());
			Command.Parameters.AddWithValue ("?destinationIp", item.Destination.Address.ToString ());
			Command.Parameters.AddWithValue ("?destinationPort", item.Destination.Port.ToString ());
			Command.Parameters.AddWithValue ("?type", Convert.ToInt32 (item.Type));
			Command.Parameters.AddWithValue ("?strat", item.Strat ?? (object)DBNull.Value);
			Command.Parameters.AddWithValue ("?poll", item.Poll ?? (object)DBNull.Value);

			object idObject = Command.ExecuteScalar ();
			item.SetId (Convert.ToInt32 (idObject));
			
			Open ();
			
			if (item is HostNtpPacket) {
				HostNtpPacket hostItem = item as HostNtpPacket;
				
				Command.CommandText = 
					"INSERT INTO hostNtpPacket(id, hostId, peerId) " +
					" VALUES( ?id, ?hostId, ?peerId);";
				Command.Prepare ();
				
				Command.Parameters.AddWithValue ("?id", hostItem.Id);
				Command.Parameters.AddWithValue ("?hostId", hostItem.Host.Id);
				Command.Parameters.AddWithValue ("?peerId", hostItem.Peer.Id);
				
				Command.ExecuteNonQuery ();
			} else if (item is PeerNtpPacket) {
				PeerNtpPacket peerItem = item as PeerNtpPacket;
				
				Command.CommandText = 
					"INSERT INTO peerNtpPacket(id, hostId, sourcePeerId) " +
					" VALUES( ?id, ?hostId, ?sourcePeerId);";
				Command.Prepare ();
				
				Command.Parameters.AddWithValue ("?id", peerItem.Id);
				Command.Parameters.AddWithValue ("?hostId", peerItem.Host.Id);
				Command.Parameters.AddWithValue ("?sourcePeerId", peerItem.Peer.Id);
				
				Command.ExecuteNonQuery ();
			} else {
				throw new NotSupportedException ("NtpPacketMapper does not support data type.");
			}
		}

		protected override void Update (NtpPacket item)
		{
			throw new NotImplementedException ();
		}

		public override System.Collections.Generic.IEnumerator<NtpPacket> GetEnumerator ()
		{
			throw new NotImplementedException ();
		}

		public DateTime? LastPackage (int hostId)
		{
			Open ();
		
			Command.CommandText =
				"SELECT MAX(p.time) FROM hostNtpPacket h " +
				"INNER JOIN ntpPacket p on h.id = p.id " +
				"WHERE h.hostId = " + hostId;
			Command.Prepare ();
			
			DateTime? result = Command.ExecuteScalar () as DateTime?;
		
			Close ();
					
			return result;
		}
	}
}
