//
// SourcePeerDatabaseMapper.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Net;
using System.Data;
using MySql.Data;
using MySql.Data.MySqlClient;
using Ntp.Analyzer.Objects;
using Ntp.Analyzer.Objects.Packet;

namespace Ntp.Analyzer.Data.Mapper
{
	/// <summary>
	/// ORM mapper for table sourcePeer.
	/// </summary>
	public sealed class SourcePeerDatabaseMapper : DatabaseMapper<SourcePeer>
	{
		internal SourcePeerDatabaseMapper (PeerDatabaseMapper peerMapper)
		{
			this.peerMapper = peerMapper;
		}

		private readonly PeerDatabaseMapper peerMapper;

		protected override bool UseCache {
			get { return true; }
		}

		protected override void Insert (SourcePeer item)
		{
			Open ();
			
			Command.CommandText = "INSERT INTO sourcePeer(ip, peerId) VALUES(?ip, ?peerId);" +
				"SELECT LAST_INSERT_ID();";
			Command.Prepare ();
           
			Command.Parameters.AddWithValue ("?ip", item.Ip);
			Command.Parameters.AddWithValue ("?peerId", item.Peer != null ? (object)item.Peer.Id : DBNull.Value);

			object idObject = Command.ExecuteScalar ();
			item.SetId (Convert.ToInt32 (idObject));
		}

		protected override void Update (SourcePeer item)
		{
			throw new NotImplementedException ();
		}

		/// <summary>
		/// Read all data from table in a sequential manner.
		/// </summary>
		/// <returns>The enumerator.</returns>
		public override System.Collections.Generic.IEnumerator<SourcePeer> GetEnumerator ()
		{
			if (HasContent) {
				foreach (SourcePeer item in Content)
					yield return item;
			
				yield break;
			}
							
			Open ();
			Command.CommandText = "SELECT id, ip, peerId FROM sourcePeer;";
			MySqlDataReader reader = Command.ExecuteReader ();

			while (reader.Read()) {
				int id = Convert.ToInt32 (reader ["id"]);
				string ip = reader ["ip"].ToString ();
				int? peerId = reader ["peerId"] != DBNull.Value ? Convert.ToInt32 (reader ["peerId"]) : (int?)null;
				Peer peer = peerId.HasValue ? peerMapper [peerId.Value] : null;
				
				SourcePeer sourcePeer = new SourcePeer (id, IPAddress.Parse (ip), peer);
				
				AddItem (sourcePeer);
				
				yield return sourcePeer;
			}
			
			Close ();
		}
	}
}
