//
// CommandController.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Linq;
using Ntp.Monitor.Server;
using Ntp.Analyzer.Gui.Data;
using Ntp.Analyzer.Gui.Model;
using Ntp.Analyzer.Gui.Window;

namespace Ntp.Analyzer.Gui.Control
{
    public sealed class CommandController
    {
        public CommandController (MainWindowController parent)
        {
            this.parent = parent;
            window = new CommandDialog (this);
        }

        private readonly MainWindowController parent;
        private readonly CommandDialog window;

        public void Show ()
        {
            window.InitializeTree (HostDataStore.Instance.Hosts.ToArray ());
            InitializeData ();
            window.ShowAll ();
        }

        private void InitializeData ()
        {
            foreach (ICommandDescription command in CommandFactory.Commands.OrderBy(c => c.Name)) {
                window.AddRow (command.Name);
            }
        }

        public void CommandSelected (string command, Host[] hosts)
        {
            this.parent.ExecuteCommand (command, hosts);
        }
    }
}
