//
// ActivityLog.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

namespace Ntp.Analyzer.Log
{
    public class ActivityLog : LogBase, IEnumerable<String>
    {
        public ActivityLog()
        {
            activity = new List<string>(2001);
        }

        private readonly List<String> activity;
        private readonly Object locker = new Object();

        public override void WriteLine(string text, Severity severity)
        {
            string severityText;

            switch (severity)
            {
                case Severity.Error:
                    severityText = "E";
                    break;
                case Severity.Warn:
                    severityText = "W";
                    break;
                case Severity.Notice:
                    severityText = "N";
                    break;
                case Severity.Info:
                    severityText = "I";
                    break;
                case Severity.Debug:
                    severityText = "D";
                    break;
                default:
                    throw new ApplicationException("Unknown severity level.");
            }

            DateTime now = DateTime.Now;

            string entry = String.Concat(
                now.ToString("HH:mm:ss"),
                " ", severityText, "  ",
                text);

            lock (locker)
            {
                if (activity.Count == 1000)
                    activity.RemoveAt(0);

                activity.Add(entry);
            }
        }

        public override void WriteLine(Exception exception)
        {
            WriteLine(exception.Message, Severity.Error);
            WriteLine(exception.StackTrace, Severity.Debug);
        }

        public IEnumerator<string> GetEnumerator()
        {
            return activity.GetEnumerator();
        }

        System.Collections.IEnumerator System.Collections.IEnumerable.GetEnumerator()
        {
            return activity.GetEnumerator();
        }
    }
}
