//
// NtpPacket.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Net;

namespace Ntp.Analyzer.Objects.Packet
{
    public abstract class NtpPacket : PersistentObject
    {
        private readonly IPEndPoint destination;
        private readonly int? poll;
        private readonly IPEndPoint source;
        private readonly int? strat;
        private readonly DateTime time;
        private readonly NtpPacketType type;
        private readonly NtpMajorVersion version;

        public NtpPacket(
            DateTime time,
            IPEndPoint source,
            IPEndPoint destination,
            NtpMajorVersion version,
            NtpPacketType type
            )
        {
            this.time = time;
            this.source = source;
            this.destination = destination;
            this.version = version;
            this.type = type;
        }

        public NtpPacket(
            DateTime time,
            IPEndPoint source,
            IPEndPoint destination,
            NtpMajorVersion version,
            NtpPacketType type,
            int strat,
            int poll
            )
            : this(time, source, destination, version, type)
        {
            this.strat = strat;
            this.poll = poll;
        }

        public DateTime Time
        {
            get { return time; }
        }

        public IPEndPoint Source
        {
            get { return source; }
        }

        public IPEndPoint Destination
        {
            get { return destination; }
        }

        public NtpMajorVersion Version
        {
            get { return version; }
        }

        public NtpPacketType Type
        {
            get { return type; }
        }

        public int? Strat
        {
            get { return strat; }
        }

        public int? Poll
        {
            get { return poll; }
        }
    }
}