//
// Peer.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Ntp.Analyzer.Objects
{
    public sealed class Peer : NamedObject
    {
        private readonly string ip;
        private readonly TimeServer server;

        public Peer(int id, string name, string ip, TimeServer server)
            : base(id, name)
        {
            this.ip = ip;
            this.server = server;
        }

        public Peer(string name, string ip, TimeServer server)
            : base(name)
        {
            this.ip = ip;
            this.server = server;
        }

        public string Ip
        {
            get { return ip; }
        }

        public TimeServer Server
        {
            get { return server; }
        }

        /// <summary>
        /// Gets the server identifier as specified on support.ntp.org.
        /// </summary>
        /// <value>The org identifier.</value>
        public int OrgId
        {
            get { return server.Id; }
        }

        /// <summary>
        /// Returns a <see cref="System.String" /> that represents the current <see cref="Ntp.Analyzer.Objects.Peer" />.
        /// </summary>
        /// <returns>
        /// A <see cref="System.String" /> that represents the current <see cref="Ntp.Analyzer.Objects.Peer" />.
        /// </returns>
        public override string ToString()
        {
            return base.ToString() + String.Format("[Peer: Name={0}, Ip={1}, OrgId={2}]", Name, Ip, OrgId);
        }
    }
}