//
// PeerReading.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Ntp.Analyzer.Objects
{
    public sealed class PeerReading : DispersionReading
    {
        private readonly double delay;
        private readonly int last;
        private readonly int reach;

        public PeerReading(
            int id,
            DateTime time,
            Host host,
            Peer peer,
            ReadingBulk bulk,
            int last,
            int reach,
            double delay,
            double offset,
            double jitter
            )
            : base(id, time, host, peer, bulk, offset, jitter)
        {
            this.reach = reach;
            this.last = last;
            this.delay = delay;
        }

        public PeerReading(
            Host host,
            Peer peer,
            ReadingBulk bulk,
            int last,
            int reach,
            double delay,
            double offset,
            double jitter
            )
            : base(host, peer, bulk, offset, jitter)
        {
            this.reach = reach;
            this.last = last;
            this.delay = delay;
        }

        public int Last
        {
            get { return last; }
        }

        public int Reach
        {
            get { return reach; }
        }

        public double Delay
        {
            get { return delay; }
        }
    }
}