//
// ServerName.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

namespace Ntp.Analyzer.Objects
{
    public sealed class ServerName
    {
        private readonly string name;

        public ServerName(string name)
        {
            this.name = name;
        }

        public string Name
        {
            get { return name; }
        }

        /// <summary>
        /// Determines whether the specified <see cref="System.Object" /> is equal to the current
        ///     <see
        ///         cref="ServerName" />
        /// .
        /// </summary>
        /// <param name="obj">
        /// The <see cref="System.Object" /> to compare with the current <see cref="ServerName" />.
        /// </param>
        /// <returns>
        ///     <c>true</c> if the specified <see cref="System.Object" /> is equal to the current
        ///     <see cref="ServerName" />; otherwise, <c>false</c>.
        /// </returns>
        /// <remarks>
        ///     <see cref="ServerName" /> is of value type
        /// </remarks>
        public override bool Equals(object obj)
        {
            if (!(obj is string))
                return false;

            return (obj as string == name);
        }

        /// <summary>
        /// Serves as a hash function for a <see cref="ServerName" /> object.
        /// </summary>
        /// <returns>A hash code for this instance that is suitable for use in hashing algorithms and data structures such as a hash table.</returns>
        /// <remarks>
        ///     <see cref="ServerName" /> is of value type
        /// </remarks>
        public override int GetHashCode()
        {
            return name.GetHashCode();
        }

        public override string ToString()
        {
            return name;
        }
    }
}