//
// SourceEntry.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System.Net;

namespace Ntp.Analyzer.Objects
{
    /// <summary>
    /// The ntp.conf configuration file is read at initial startup by the ntpd(8)
    /// daemon in order to specify the synchronization sources, modes and other
    /// related information.  Usually, it is installed in the /etc directory, but
    /// could be installed elsewhere (see the daemon's -c command line option).
    /// </summary>
    /// <remarks>
    /// Source: man page of ntp.conf from FreeBSD, dated December 21 2006
    /// </remarks>
    public sealed class NtpConfEntry
    {
        private readonly IPAddress address;
        private readonly string name;
        private readonly int? orgId;
        private readonly TimeServerRole role;

        public NtpConfEntry(TimeServerRole role, IPAddress address, string name, int? orgId)
        {
            this.role = role;
            this.address = address;
            this.name = name;
            this.orgId = orgId;
        }

        public TimeServerRole Role
        {
            get { return role; }
        }

        public IPAddress Address
        {
            get { return address ?? new IPAddress(0); }
        }

        public string Name
        {
            get { return name; }
        }

        public int? OrgId
        {
            get { return orgId; }
        }

        public override string ToString()
        {
            return string.Format("{0}, {1}, {2}, OrgId={3}]", Role, Address, Name, OrgId);
        }
    }
}