//
// StatusLine.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using Ntp.Analyzer.Objects.Live;

namespace Ntp.Analyzer.Objects
{
    /// <summary>
    /// A status line for an NTP Server containing information about configuration, peer and server details.
    /// </summary>
    public sealed class StatusLine
    {
        private readonly NtpConfEntry conf;
        private readonly AssociationEntry peer;
        private readonly TimeServer server;

        /// <summary>
        /// Initializes a new instance of the <see cref="Ntp.Analyzer.Objects.StatusLine" /> class.
        /// </summary>
        /// <param name="peer">Peer.</param>
        /// <param name="conf">Conf.</param>
        /// <param name="server">Server.</param>
        public StatusLine(AssociationEntry peer, NtpConfEntry conf, TimeServer server)
        {
            this.peer = peer;
            this.conf = conf;
            this.server = server;
        }

        /// <summary>
        /// Gets the peer for this line.
        /// </summary>
        /// <value>The peer.</value>
        public AssociationEntry Peer
        {
            get { return peer; }
        }

        /// <summary>
        /// Gets the local configuration for this line
        /// </summary>
        /// <value>The conf.</value>
        public NtpConfEntry Conf
        {
            get { return conf; }
        }

        /// <summary>
        /// Gets the peer server descriptor for this line.
        /// </summary>
        /// <value>The server.</value>
        public TimeServer Server
        {
            get { return server; }
        }
    }
}