//
// HostGraphJob.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Linq;
using Ntp.Analyzer.Log;
using Ntp.Analyzer.Data;
using Ntp.Analyzer.Graph;
using Ntp.Analyzer.Objects;
using Ntp.Analyzer.Config.Graph;

namespace Ntp.Analyzer.Process.Job
{
    public sealed class HostGraphJob : StreamJob
    {
        public HostGraphJob (HostGraphConfiguration config, LogBase log)
			: base(config, log)
        {
            this.config = config;
        }

        private readonly HostGraphConfiguration config;

        public override string Name {
            get { return "Host graph generation"; }
        }

        public override int Priority {
            get { return 20; }
        }

        protected override void InternalExecute ()
        {
            // Find host in database.
            Host host;
 
            try {
                host = DataFace.Instance.Hosts.Single (h => h.Name == config.ServerName);
            } catch (Exception) {
                Log.WriteLine ("Hostname not found in database: " + config.ServerName, Severity.Warn);
                return;
            }		
		
            HostGraph graph = new HostGraph (config, host);
            SaveStream (graph);
        }
    }
}
