//
// DatabaseConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Collections.Generic;
using Ntp.Config;

namespace Ntp.Analyzer.Config
{
    public sealed class DatabaseConfiguration : ConfigurationBase
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Ntp.Analyzer.Config.DatabaseConfiguration"/> class.
        /// </summary>
        /// <param name="configName">Config name.</param>
        /// <param name="host">Host.</param>
        /// <param name="name">Name.</param>
        /// <param name="user">User.</param>
        /// <param name="pass">Pass.</param>
        private DatabaseConfiguration (
            string configName,
            string host,
            string name,
            string user,
            string pass
        )
            : base(configName)
        {
            this.host = host;
            this.name = name;
            this.user = user;
            this.pass = pass;
        }

        private readonly string host;
        private readonly string name;
        private readonly string user;
        private readonly string pass;

        /// <summary>
        /// Gets the database connection string.
        /// </summary>
        /// <value>The database connection string.</value>
        public string ConnectionString {
            get {
                return String.Format (
                    "server={0};database={1};userid={2};password={3}",
                    host, name, user, pass);
            }
        }

        /// <summary>
        /// Create the specified block.
        /// </summary>
        /// <param name="block">Block.</param>
        /// <example>
        /// Database {
        /// 	DatabaseHost 192.168.1.1
        /// 	DatabaseName ntpa
        /// 	DatabaseUser ntpau
        /// 	DatabasePass x341
        /// }
        /// </example>
        public static DatabaseConfiguration Create (ConfigurationBlock config)
        {
            Dictionary<String, String> options = GetOptions (new String[] {
                "Database",
                "Host",
                "Name",
                "User",
                "Pass"
            }, config.Lines);
			
            return new DatabaseConfiguration (
                GetOptionConfigName (options, "Database"),
                GetOptionString (options, "Host", "SPECIFY Host"),
                GetOptionString (options, "Name", "SPECIFY Name"),
                GetOptionString (options, "User", "SPECIFY User"),
                GetOptionString (options, "Pass", "SPECIFY Pass"));
        }
    }
}
