//
// DirectoryCollection.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Collections.Generic;
using System.Linq;
using Ntp.Analyzer.Export;
using Ntp.Config;

namespace Ntp.Analyzer.Config.Destination
{
    public sealed class DirectoryCollection : DestinationCollection
    {
        public const string Identifier = "Destinations";
        private readonly IEnumerable<DirectoryStreamDestination> destinations;
        private readonly string prefix;

        public DirectoryCollection (
            string configName,
            int indentLevel,
            IEnumerable<DirectoryStreamDestination> destinations,
            string prefix)
            : base(configName, indentLevel)
        {
            this.destinations = destinations;
            this.prefix = prefix;
        }

        public override IEnumerable<StreamDestination> Destinations {
            get { return destinations; }
        }

        public override string ToString ()
        {
            List<Object> values = new List<Object> ();
            values.Add (null);
            values.Add (prefix);

            IEnumerable<String> names = Destinations.Select (f => f.Location);
            values.AddRange (names);

            List<String> settings = new List<String> ();
            settings.Add (Identifier);
            settings.Add ("Prefix");

            int num = destinations.Count ();

            for (int i = 0; i < num; i++)
                settings.Add ("File");

            return ConfigText (settings.ToArray (), values.ToArray ());
        }

        public static DirectoryCollection Create (
            ServerConfiguration server,
            ConfigurationBlock config)
        {
            List<DirectoryStreamDestination> directories = new List<DirectoryStreamDestination> ();

            String[] destinationLines = FindSingleBlock (Identifier, config).Lines;
            string prefix = GetOptions (new[] { "Prefix" }, destinationLines) ["Prefix"];

            foreach (string destination in GetMultiOption("Directory", destinationLines))
                directories.Add (new DirectoryStreamDestination (server.FilePath, destination, prefix));

            return new DirectoryCollection (String.Empty, config.IndentLevel + 1, directories, prefix);
        }
    }
}