//
// WebLinkCollection.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Collections.Generic;
using System.Linq;
using Ntp.Analyzer.Export;
using Ntp.Config;

namespace Ntp.Analyzer.Config.Destination
{
    public sealed class WebLinkCollection : ConfigurationBase
    {
        public const string Identifier = "Links";
        private readonly IList<WebLink> links;

        public WebLinkCollection (
            string configName,
            int indentLevel,
            IList<WebLink> links)
            : base(configName, indentLevel)
        {
            this.links = links;
        }

        protected override IEnumerable<object> Items {
            get { return Destinations; }
        }

        public IList<WebLink> Destinations {
            get { return links; }
        }

        public override string ToString ()
        {
            List<Object> values = new List<Object> ();
            values.Add (null);

            IEnumerable<String> names = Destinations.Select (l => l.Link);
            values.AddRange (names);

            List<String> settings = new List<string> ();
            settings.Add (Identifier);

            int num = links.Count ();

            for (int i = 0; i < num; i++)
                settings.Add ("Link");

            return ConfigText (settings.ToArray (), values.ToArray ());
        }

        public static WebLinkCollection Create (
            ServerConfiguration server,
            ConfigurationBlock config)
        {
            List<WebLink> links = new List<WebLink> ();
            ConfigurationBlock linkBlock = FindSingleBlock (Identifier, config);
            foreach (string link in GetMultiOption("Link", linkBlock))
                links.Add (new WebLink (link));

            return new WebLinkCollection (String.Empty, config.IndentLevel + 1, links);
        }
    }
}