//
// DispersionGraphConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using Ntp.Analyzer.Config.Destination;
using Ntp.Analyzer.Graph.Interface;

namespace Ntp.Analyzer.Config.Graph
{
    /// <summary>
    /// Base class for dispersion graph configurations.
    /// </summary>
    public abstract class DispersionGraphConfiguration : GraphBaseConfiguration, IDispersionGraphConfiguration
    {
        protected DispersionGraphConfiguration (
            ServerConfiguration server,
            string configName,
            int indentLevel,
            string title,
            int width,
            int height,
            int timespan,
            double filterFactor,
            double offset,
            double jitter,
            DestinationCollection destinations,
            WebLinkCollection links)
            : base (
            server,
            configName,
            indentLevel,
            title,
            width,
            height,
            timespan,
            filterFactor,
            destinations,
            links)
        {
            this.jitter = jitter;
            this.offset = offset;
        }

        private readonly double jitter;
        private readonly double offset;

        /// <summary>
        /// Gets the jitter multiplication factor.
        /// </summary>
        /// <value>The factor.</value>
        public double Jitter {
            get { return jitter; }
        }

        /// <summary>
        /// Gets the offset multiplication factor.
        /// </summary>
        /// <value>The factor.</value>
        public double Offset {
            get { return offset; }
        }
    }
}