//
// NodeConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Ntp.Config;
using System.Collections.Generic;

namespace Ntp.Analyzer.Config.Net
{
    public sealed class ClusterConfiguration : ConfigurationBase
    {
        public ClusterConfiguration (
            string name,
            int indentLevel,
            IEnumerable<NodeConfiguration> nodes)
            : base(name, indentLevel)
        {
            this.nodes = nodes;
        }

        private readonly IEnumerable<NodeConfiguration> nodes;

        public IEnumerable<NodeConfiguration> Nodes {
            get { return nodes; }
        }

        public const string Identifier = "Cluster";
        private static readonly String[] Params = new[] {
            Identifier,
            "Node"
        };

        protected override IEnumerable<Object> Items {
            get {
                return new object[] {
                    ConfigName,
                    Nodes
                };
            }
        }

        public static ClusterConfiguration Create (ConfigurationBlock config)
        {
            if (config == null)
                return null;

            OptionSet options = GetOptions (Params, config);

            List<NodeConfiguration> nodes = new List<NodeConfiguration> ();

            foreach (ConfigurationBlock nodeBlock in FindBlocks(Params[1], config)) {
                NodeConfiguration node = NodeConfiguration.Create (nodeBlock);

                if (node != null) {
                    nodes.Add (node);
                }
            }

            return new ClusterConfiguration (
                GetOptionConfigName (options, Params [0], Params [0], true),
                config.IndentLevel,
                nodes);
        }
    }
}