//
// WebSourceCollection.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using Ntp.Analyzer.Export;
using Ntp.Config;
using System.Linq;
using Ntp.Web;
using Ntp.Analyzer.Servable;
using Ntp.Analyzer.Config.Page;
using Ntp.Analyzer.Config.Graph;

namespace Ntp.Analyzer.Config.Net
{
    public sealed class WebSourceCollection : ConfigurationBase
    {
        public WebSourceCollection (
            string configName,
            int indentLevel,
            IList<WebFile> files)
            : base (configName, indentLevel)
        {
            this.files = files;
        }

        public const string Identifier = "Static";
        private readonly IList<WebFile> files;

        protected override IEnumerable<Object> Items {
            get { return Files; }
        }

        public IList<WebFile> Files {
            get { return files; }
        }

        public override string ToString ()
        {
            List<Object> values = new List<Object> ();
            values.Add (null);

            IEnumerable<String> names = Files.Select (f => f.File);
            values.AddRange (names);

            List<String> settings = new List<String> ();
            settings.Add (Identifier);

            int num = files.Count ();

            for (int i = 0; i < num; i++)
                settings.Add ("File");

            return ConfigText (settings.ToArray (), values.ToArray ());
        }

        public static WebSourceCollection Create (
            ConfigurationBlock config,
            IEnumerable<PageConfigurationBase> pages,
            IEnumerable<GraphBaseConfiguration> graphs,
            string domain, string webPath, string filePath)
        {
            List<IServable> files = new List<IServable> ();
            ConfigurationBlock sourceBlock = FindSingleBlock (Identifier, config);
            foreach (string file in GetMultiOption("File", sourceBlock))
                files.Add (new StaticServable (domain, webPath, filePath, file));

            foreach (string pageName in GetMultiOption("Page", sourceBlock)) {
                PageConfigurationBase page = pages.SingleOrDefault (p => p.ConfigName == pageName);
                
                // TODO: LOGGING
                if (Page == null)
                    continue;
                                             
                files.Add (new CachedServable (domain, page.WebPath, page.FilePath, page.Destinations.First().Location));
            }
            
            foreach (string graphName in GetMultiOption("Graph", sourceBlock)) {
                GraphBaseConfiguration graph = graphs.SingleOrDefault (g => g.ConfigName== graphName);
                
                // TODO: LOGGING
                if (graph == null)
                    continue;
                                             
                files.Add (new CachedServable (domain, graph.WebPath, graph.FilePath, graph.Destinations.First().Location));
            }
            
            return new WebSourceCollection (String.Empty, config.IndentLevel + 1, files);
        }
    }
}
