//
// WebListenerConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using Ntp.Config;

namespace Ntp.Analyzer.Config.Net
{
    public sealed class WebListenerConfiguration : EndPointConfiguration
    {
        public WebListenerConfiguration (
            string name,
            int indentLevel,
            string ip,
            int port,
            int timeout,
            WebResourceConfiguration resource)
        : base (name, indentLevel, ip, port)
        {
            this.timeout = timeout;
            this.resource = resource;
        }

        public const string Identifier = "Web";
        private static readonly String[] Params = new[] {
            Identifier,
            "IP",
            "Port",
            "Timeout",
            WebResourceConfiguration.Identifier
        };
        
        private readonly int timeout;
        private readonly WebResourceConfiguration resource;

        /// <summary>
        /// Gets the timeout.
        /// </summary>
        /// <value>The timeout.</value>
        public int Timeout {
            get { return timeout; }
        }

        public WebResourceConfiguration Resource {
            get { return resource; }
        }

        protected override IEnumerable<Object> Items {
            get {
                return new object[] {
                    ConfigName,
                    Ip,
                    Port,
                    Timeout,
                    resource
                };
            }
        }

        public override string ToString ()
        {
            return ConfigText (Params, Items);
        }

        public static WebListenerConfiguration Create (ConfigurationBlock config)
        {
            Dictionary<String, String> options = GetOptions (Params, config);

            return new WebListenerConfiguration (
                GetOptionConfigName (options, Params [0], String.Empty, false),
                config.IndentLevel,
                GetOptionString (options, "IP", Params [0], false, "0.0.0.0"),
                GetOptionInteger (options, "Port", Params [0], false, 80),
                GetOptionInteger (options, "Timeout", Params [0], false, 10000),
                WebResourceConfiguration.Create (config)
            );
        }
    }
}
