//
// WebResourceConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Ntp.Config;
using System.Collections.Generic;

namespace Ntp.Analyzer.Config.Net
{
    public sealed class WebResourceConfiguration : ConfigurationBase
    {
        public WebResourceConfiguration (
            string configName,
            int indentLevel,
            string domain,
            string filePath,
            string webPath,
            WebSourceCollection sources
        )
            : base (configName, indentLevel)
        {
            this.domain = domain;
            this.filePath = filePath;
            this.webPath = webPath;
            this.sources = sources;
        }

        public const string Identifier = "Resources";
        private static readonly String[] Params = new[] {
            Identifier,
            "Domain",
            "FilePath",
            "WebPath"
        };
        private readonly string domain;
        private readonly string filePath;
        private readonly string webPath;
        private readonly WebSourceCollection sources;

        public string Domain {
            get { return domain; }
        }

        public string FilePath {
            get { return filePath; }
        }

        public string WebPath {
            get { return webPath; }
        }

        public WebSourceCollection Sources {
            get { return sources; }
        }

        protected override IEnumerable<Object> Items {
            get {
                return new object[] {
                    ConfigName,
                    Domain,
                    FilePath,
                    WebPath,
                    sources
                };
            }
        }

        public override string ToString ()
        {
            return ConfigText (Params, Items);
        }

        public static WebResourceConfiguration Create (ConfigurationBlock config)
        {
            if (config == null)
                return null;

            Dictionary<String, String> options = GetOptions (Params, config);
            string domain = GetOptionString (options, Params [1], Params [0], true);
            string filePath = GetOptionString (options, Params [2], Params [0], true);
            string webPath = GetOptionString (options, Params [3], Params [0], true);

            return new WebResourceConfiguration (
                GetOptionConfigName (options, Params [0], String.Empty, false),
                config.IndentLevel,
                domain,
                filePath,
                webPath,
                WebSourceCollection.Create (config, domain, webPath, filePath)
            );
        }
    }
}
