//
// NotifyConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using Ntp.Config;

namespace Ntp.Analyzer.Config
{
	public sealed class NotifyConfiguration : ScheduledJobConfiguration
	{
		private NotifyConfiguration (
            string configName,
			bool initialRun,
			int frequency,
			string mail,
			string subject,
			string sender,
			string server,
			int port)
			: base (configName, frequency, initialRun)
		{
			this.mail = mail;
			this.subject = subject;
			this.sender = sender;
			this.server = server;
			this.port = port;
		}

		private readonly string mail;
		private readonly string subject;
		private readonly string sender;
		private readonly string server;
		private readonly int port;

		public string Mail {
			get { return mail; }
		}

		public string Subject {
			get { return subject; }
		}

		public string Sender {
			get { return sender; }
		}

		public string SmptServer {
			get { return server; }
		}

		public int SmtpPort {
			get { return port; }
		}

		public static NotifyConfiguration Create (ConfigurationBlock config)
		{
			List<String> keywords = new List<String> () {
                "Notify",
				"InitialRun",
				"Frequency",
				"Mail",
				"Subject",
				"Sender",
				"Smtp",
				"Port"
			};
			
			Dictionary<String, String> options = GetOptions (keywords.ToArray (), config.Lines);
			
			return new NotifyConfiguration (
                options ["Notify"].Replace ("{", String.Empty).Trim (),
				ConvertToBoolean (options ["InitialRun"]),
				ConvertToInteger (options ["Frequency"]),
				options ["Mail"],
				options ["Subject"],
				options ["Sender"],
				options ["Smtp"],
				ConvertToInteger (options ["Port"])
			);
		}
	}
}
