//
// SummeryCollection.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Linq;
using Ntp.Config;

namespace Ntp.Analyzer.Config.Page.Collection
{
    public sealed class SummeryCollection : ConfigurationBase
    {
        public const string Identifier = "Summeries";
        private readonly List<PeerSummeryPageConfiguration> pages;

        public SummeryCollection(
            string configName,
            int indentLevel,
            IEnumerable<PeerSummeryPageConfiguration> pages)
            : base(configName, indentLevel)
        {
            this.pages = new List<PeerSummeryPageConfiguration>(pages);
        }

        protected override IEnumerable<Object> Items
        {
            get { return pages; }
        }

        public IEnumerable<PeerSummeryPageConfiguration> Pages
        {
            get { return pages; }
        }

        public override string ToString()
        {
            List<Object> values = new List<Object>();
            values.Add(null);

            IEnumerable<String> names = pages.Select(g => g.ConfigName);
            values.AddRange(names);

            List<String> settings = new List<string>();
            settings.Add(Identifier);

            int num = names.Count();

            for (int i = 0; i < num; i++)
                settings.Add("PeerSummeryPage");

            return ConfigText(settings.ToArray(), values.ToArray());
        }

        public static SummeryCollection Create(
            ServerConfiguration server,
            IEnumerable<PeerSummeryPageConfiguration> peerSummeries,
            ConfigurationBlock config,
            string configPath)
        {
            List<PeerSummeryPageConfiguration> summeries = new List<PeerSummeryPageConfiguration>();
            foreach (string name in GetMultiOption("PeerSummeryPage", FindSingleBlock(Identifier, config)))
            {
                PeerSummeryPageConfiguration summery = peerSummeries.SingleOrDefault(ps => ps.ConfigName == name);

                if (summery != null)
                    summeries.Add(summery);
                else
                {
                    ConfigError("Cannot find PeerSummeryPage " + name + " specified in HostPage");
                }
            }

            return new SummeryCollection(String.Empty, config.IndentLevel + 1, summeries);
        }
    }
}