//
// ReadingBulkConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using Ntp.Config;

namespace Ntp.Analyzer.Config
{
	public sealed class ReadingBulkConfiguration : ScheduledJobConfiguration
	{
		private ReadingBulkConfiguration (string name, int frequency, bool initialRun)
			:base (name, frequency, initialRun)
		{
			this.name = name;
		}

		private readonly string name;

		public string Name {
			get { return name; }
		}

		public static ReadingBulkConfiguration Create (ConfigurationBlock config)
		{
			// ReadingBulkConfiguration is optional.
			if (config == null)
				return null;
		
			List<String> keywords = new List<String> () {
				"Name",
				"Frequency",
				"InitialRun"
			};
			
			Dictionary<String, String> options = GetOptions (keywords.ToArray (), config.Lines);

			int frequency = ConvertToInteger (options ["Frequency"]);
			bool initialRun = ConvertToBoolean (options ["InitialRun"]);

			return new ReadingBulkConfiguration (
				options ["Name"],
				frequency,
				initialRun
			);
		}
	}
}
