//
// ScheduleConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using Ntp.Process;
using Ntp.Config;

namespace Ntp.Analyzer.Config.Schedule
{
    public sealed class ScheduleConfiguration : ScheduleConfigurationBase
    {
        public ScheduleConfiguration (
            string configName,
            int indentLevel,
            int? frequency,
            bool? initialRun,
            bool? fixedRun)
        : base (configName, indentLevel, frequency, initialRun, fixedRun)
        {
        }

        public const string Identifier = "Schedule";
        private static readonly String[] Params = new[] {
            Identifier,
            "Frequency",
            "InitialRun",
            "FixedRun",
            "Job"
        };

        protected override IEnumerable<Object> Items {
            get {
                return new object[] {
                    ConfigName,
                    Frequency,
                    (InitialRun ?? false) ? 1 : 0,
                    (FixedRun ?? false) ? 1 : 0,
                    Jobs
                };
            }
        }

        public override string ToString ()
        {
            return ConfigText (Params, Items);
        }

        public static ScheduleConfiguration Create (ConfigurationBlock config)
        {
            OptionSet options = GetOptions (Params, config);
            int frequency = GetOptionInteger (options, Params [1], Params [0], false);
            bool initialRun = GetOptionBoolean (options, Params [2], Params [0], false);
            bool fixedRun = GetOptionBoolean (options, Params [3], Params [0], false);
            
            ScheduleConfiguration schedule = new ScheduleConfiguration (
                GetOptionConfigName (options, Params [0], Params [0], true),
                config.IndentLevel,
                frequency != 0 ? (int?)frequency : null,
                initialRun ? (bool?)initialRun : null,
                fixedRun ? (bool?)fixedRun : null
            );
            
            ConfigurationBlock[] jobBlocks = FindBlocks (Params [4], config);
            foreach (ConfigurationBlock jobBlock in jobBlocks) {
                schedule.jobs.Add (JobConfiguration.Create (schedule, config));
            }
            
            return schedule;
        }
    }
}
