//
// ServerSubConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using Ntp.Process;
using Ntp.Config;

namespace Ntp.Analyzer.Config
{
    /// <summary>
    /// Configuration class for subsections of a <see cref="Ntp.Analyzer.Config.ServerConfiguration" />.
    /// </summary>
    public abstract class ServerSubConfiguration : ConfigurationBase
    {
        private readonly ServerConfiguration server;

        protected ServerSubConfiguration (
            ServerConfiguration server,
            string configName,
            int indentLevel)
            : base (configName, indentLevel)
        {
            this.server = server;
        }

        /// <summary>
        /// Gets the name of the server in the <see cref="Ntp.Analyzer.Config.ServerSubConfiguration" />.
        /// </summary>
        /// <value>The name of the server.</value>
        public string ServerName {
            get { return server.ServerName; }
        }

        /// <summary>
        /// Gets the config file in the <see cref="Ntp.Analyzer.Config.ServerSubConfiguration" />.
        /// </summary>
        /// <value>The config file.</value>
        public string ConfigFile {
            get { return server.ConfigFile; }
        }

        /// <summary>
        /// Gets the host identifier in the <see cref="Ntp.Analyzer.Config.ServerSubConfiguration" />.
        /// </summary>
        /// <value>The host identifier.</value>
        public int HostId {
            get { return server.HostId; }
        }

        /// <summary>
        /// Gets the web path in the <see cref="Ntp.Analyzer.Config.ServerSubConfiguration" />.
        /// </summary>
        /// <value>The web path.</value>
        public string WebPath {
            get { return server.WebPath; }
        }
        
        public string FilePath {
            get { return server.FilePath; }
        }
    }
}