//
// HostIOStatConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Collections.Generic;
using Ntp.Config;
using Ntp.Analyzer.Config.Root;

namespace Ntp.Analyzer.Config.Stats
{
    public sealed class HostIOStatConfiguration : StatsConfiguration
    {
        private HostIOStatConfiguration (
            string configName,
            int indentLevel,
            ServerConfiguration server,
            ReadingBulkConfiguration bulk,
            int frequency,
            bool initialRun,
            bool fixedRun
        )
            : base(configName, indentLevel, server, bulk, frequency, initialRun, fixedRun)
        {
        }

        private static readonly String[] Params = new[] {
            "HostIOStats",
            "Frequency",
            "InitialRun",
            "FixedRun"
        };

        protected override IEnumerable<Object> Items {
            get {
                return new object[] {
                    ConfigName,
                    Frequency,
                    InitialRun ? 1 : 0,
                    FixedRun ? 1 : 0
                };
            }
        }

        public override string ToString ()
        {
            return ConfigText (Params, Items);
        }

        public static HostIOStatConfiguration Create (
            ServerConfiguration server,
            ReadingBulkConfiguration bulk,
            ConfigurationBlock config)
        {
            OptionSet options = GetOptions (Params, config);

            string configName = GetOptionConfigName (options, Params[0], String.Empty, false);

            bool initialRun = false;
            bool fixedRun = false;
            int frequency;

            ReadingBulkConfiguration bulkConfig = null;

            // TODO: Implement handling of multimple ReadingBulkConfigurations
            if (!Int32.TryParse (options[Params[1]], out frequency)) {
                if (bulk != null && options[Params[1]] == bulk.Name)
                    bulkConfig = bulk;
                else {
                    ConfigError ("HostIOStats->Frequency is not defied correctly (" + configName + ").");
                }
            } else {
                frequency = GetOptionInteger (options, Params[1], Params[0], true);
                initialRun = GetOptionBoolean (options, Params[2], Params[0], true);
                fixedRun = GetOptionBoolean (options, Params[3], Params[0], true);
            }

            return new HostIOStatConfiguration (
                configName,
                config.IndentLevel,
                server,
                bulkConfig,
                frequency,
                initialRun,
                fixedRun);
        }
    }
}