//
// ReadingBulkConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Collections.Generic;
using Ntp.Config;
using Ntp.Process;

namespace Ntp.Analyzer.Config.Root
{
    public sealed class ReadingBulkConfiguration : JobConfigurationBase
    {
        private ReadingBulkConfiguration (
            string configName,
            int indentLevel,
            string name,
            int frequency,
            bool initialRun,
            bool fixedRun)
            : base(
                configName,
                indentLevel,
                frequency,
                initialRun,
                fixedRun)
        {
            this.name = name;
        }

        public const string Identifier = "Reading";
        private static readonly String[] Params = new[] {
            Identifier,
            "Name",
            "Frequency",
            "InitialRun",
            "FixedRun"
        };
        private readonly string name;

        public string Name {
            get { return name; }
        }

        protected override IEnumerable<Object> Items {
            get {
                return new object[] {
                    ConfigName,
                    Name,
                    Frequency,
                    InitialRun ? 1 : 0,
                    FixedRun ? 1 : 0
                };
            }
        }

        public override string ToString ()
        {
            return ConfigText (Params, Items);
        }

        public static ReadingBulkConfiguration Create (ConfigurationBlock config)
        {
            if (config == null)
                return null;

            Dictionary<String, String> options = GetOptions (Params, config);

            return new ReadingBulkConfiguration (
                GetOptionConfigName (options, Params [0], String.Empty, false),
                config.IndentLevel,
                GetOptionString (options, "Name", Params [0], true),
                GetOptionInteger (options, "Frequency", Params [0], true),
                GetOptionBoolean (options, "InitialRun", Params [0], true),
                GetOptionBoolean (options, "FixedRun", Params [0], true)
            );
        }
    }
}