//
// StatsConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using Ntp.Analyzer.Config.Root;
using Ntp.Process;

namespace Ntp.Analyzer.Config.Stats
{
    public abstract class StatsConfiguration : JobConfigurationBase
    {
        protected StatsConfiguration (
            string configName,
            int indentLevel,
            ServerConfiguration server,
            ReadingBulkConfiguration bulk,
            int frequency,
            bool initialRun,
            bool fixedRun
        )
            : base(configName, indentLevel, frequency, initialRun, fixedRun)
        {
            this.server = server;
            this.bulk = bulk;
        }

        private readonly ServerConfiguration server;
        private readonly ReadingBulkConfiguration bulk;

        public ServerConfiguration Server {
            get { return server; }
        }

        public ReadingBulkConfiguration Bulk {
            get { return bulk; }
        }

        public override bool InitialRun {
            get { return bulk != null ? bulk.InitialRun : base.InitialRun; }
        }

        public override bool FixedRun {
            get { return bulk != null ? bulk.FixedRun : base.FixedRun; }
        }

        public override int Frequency {
            get { return bulk != null ? bulk.Frequency : base.Frequency; }
        }
    }
}
