//
// TcpdumpStatConfiguration.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using Ntp.Config;

namespace Ntp.Analyzer.Config.Stats
{
	public sealed class TcpdumpStatConfiguration : StatsConfiguration
	{
		private TcpdumpStatConfiguration (
            string configName,
			ServerConfiguration server,
			ReadingBulkConfiguration bulk,
			int frequency,
			bool initialRun,
			string dumpFile
		)
			: base(configName, server, bulk, frequency, initialRun)
		{
			this.dumpFile = dumpFile;
		}

		private readonly string dumpFile;

		public string DumpFile {
			get { return dumpFile; }
		}

		public static TcpdumpStatConfiguration Create (
			ServerConfiguration server,
			ReadingBulkConfiguration bulk, 
			ConfigurationBlock config)
		{
			List<String> keywords = new List<String> () {
                "",
                "Frequency",
				"InitialRun",
				"DumpFile"
			};
			
			Dictionary<String, String> options = GetOptions (keywords.ToArray (), config.Lines);

			bool initialRun = false;
			int frequency = 0;
			ReadingBulkConfiguration bulkConfig = null;
			
			// TODO: Implement handling of multimple ReadingBulkConfigurations
			if (!Int32.TryParse (options ["Frequency"], out frequency)) {
				if (bulk != null && options ["Frequency"] == bulk.ConfigName)
					bulkConfig = bulk;
				else
					throw new ApplicationException ("Frequency is not defied correctly.");
			} else {
				frequency = ConvertToInteger (options ["Frequency"]);
				initialRun = ConvertToBoolean (options ["InitialRun"]);
			}
			
			return new TcpdumpStatConfiguration (
                "",
				server,
				bulkConfig,
				frequency,
				initialRun,
				options ["DumpFile"]);
		}
	}
}
