//
// DispersionGraph.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Collections.Generic;
using System.Drawing;
using NPlot;
using Ntp.Analyzer.Config.Graph;
using Ntp.Analyzer.Graph.Interface;

namespace Ntp.Analyzer.Graph
{
    /// <summary>
    /// A dispersion graph contains an series of offsets and jitter values together with a time coordinate.
    /// </summary>
    public abstract class DispersionGraph : GraphBase
    {
        protected readonly List<Double> Jitter = new List<Double> ();
        protected readonly List<Double> Offset = new List<Double> ();
        protected readonly List<DateTime> Time = new List<DateTime> ();
        private readonly IDispersionGraphConfiguration config;

        protected DispersionGraph (IDispersionGraphConfiguration configuratation)
            : base(configuratation)
        {
            config = configuratation;

            Time = new List<DateTime> ();
            Offset = new List<Double> ();
            Jitter = new List<Double> ();
        }

        protected override void AddPlots ()
        {
            LinePlot offsetPlot = SetupPlot ("Offset", Color.Red, Time, Offset);
            LinePlot jitterPlot = SetupPlot ("Jitter", Color.Blue, Time, Jitter);

            if (config.Jitter != 0.0)
                Surface.Add (jitterPlot, PlotSurface2D.XAxisPosition.Bottom, PlotSurface2D.YAxisPosition.Left);

            if (config.Offset != 0.0)
                Surface.Add (offsetPlot, PlotSurface2D.XAxisPosition.Bottom, PlotSurface2D.YAxisPosition.Left);
        }
    }
}