//
// PftopImporter.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.IO;

namespace Ntp.Analyzer.Import
{
	public class PftopImporter
	{
		public PftopImporter ()
		{
		}
		//private readonly Host host;
		//private readonly ReadingBulk bulk;
		//private readonly List<HostReading> entries = new List<HostReading> ();
		/// <summary>
		/// Gets the imported entries.
		/// </summary>
		/// <value>
		/// The entries.
		/// </value>
		//public HostReading[] Entries {
		//	get { return entries.ToArray (); }
		//}

		//private List<Peer> peers;

		private void Initialize ()
		{
			//if (host == null)
			//	return;
	
			//peers = DataFace.Instance.Peers.ToList ();
		}

		/// <summary>
		/// Import data from the specified server.
		/// </summary>
		/// <param name='server'>
		/// Server to import from.
		/// </param>
		/// <remarks>
		/// ntpdc -c loopinfo -c sysinfo ntp1.innolan.dk 		
		/// </remarks>
		public void Import ()
		{
			Initialize ();
		
			System.Diagnostics.Process proc = new System.Diagnostics.Process ();
			proc.EnableRaisingEvents = false; 
			proc.StartInfo.UseShellExecute = false;
			proc.StartInfo.RedirectStandardOutput = true;
			proc.StartInfo.FileName = "pftop";
			proc.StartInfo.WorkingDirectory = "/tmp/";
			proc.StartInfo.Arguments = " -ab";
			proc.Start ();
			ReadFromStream (proc.StandardOutput);
		}

		/// <summary>
		/// Reads from stream.
		/// </summary>
		/// <param name="reader">Reader.</param>
		/// <remarks>
		/// udp   I 31.150.78.238:123     95.166.204.165:123    1:2      1    29     2   152
		/// udp   I 62.107.99.45:32827    95.166.204.165:123    1:2      1    29     2   152
		/// udp   I 90.185.181.64:11298   95.166.204.165:123    1:2      1    29     2   152
		/// udp   I 78.143.68.118:32980   95.166.204.165:123    1:2      1    29     2   152
		/// udp   O 172.20.83.1:13217     172.20.80.1:53        2:1      1    29     2   498
		/// udp   I 172.20.83.1:13217     172.20.80.1:53        1:2      1    29     2   498
		/// udp   O 172.20.83.1:52879     95.166.204.165:123    2:2      1    59     4   616
		/// udp   I 172.20.83.1:52879     95.166.204.165:123    2:2      1    59     4   616
		/// udp   O 172.20.83.1:42944     172.20.80.1:53        2:1      1    29     2   498
		/// udp   I 172.20.83.1:42944     172.20.80.1:53        1:2      1    29     2   498
		/// udp   O 172.20.83.1:36146     95.166.204.165:123    2:2      1    59    38  8304
		/// udp   I 172.20.83.1:36146     95.166.204.165:123    2:2      1    59    38  8304
		/// udp   O 172.20.83.1:41364     172.20.80.1:53        2:1      1    29     2   498
		/// udp   I 172.20.83.1:41364     172.20.80.1:53        1:2      1    29     2   498
		/// udp   O 172.20.83.1:49613     172.20.80.1:53        2:1      1    29     2   498
		/// udp   I 172.20.83.1:49613     172.20.80.1:53        1:2      1    29     2   498
		/// udp   O 172.20.83.1:40784     95.166.204.208:123    2:2      1    59     4   616
		/// udp   O 172.20.83.1:46471     172.20.80.1:53        2:1      0    30     2   498
		/// udp   I 172.20.83.1:46471     172.20.80.1:53        1:2      0    30     2   498
		/// udp   O 172.20.83.1:32026     95.166.204.208:123    2:2      0    60    44  9716
		/// udp   O 172.20.83.1:64426     172.20.80.1:53        2:1      0    30     2   498
		/// udp   I 172.20.83.1:64426     172.20.80.1:53        1:2      0    30     2   498
		/// udp   O 172.20.83.1:41887     172.20.80.1:53        2:1      0    30     2   498
		/// udp   I 172.20.83.1:41887     172.20.80.1:53        1:2      0    30     2   498
		/// udp   O 172.20.83.1:29853     95.166.204.252:123    2:2      0    60     4   616
		/// udp   O 172.20.83.1:25219     172.20.80.1:53        2:1      0    30     2   498
		///
		/// ...
		///
		/// </remarks>
		private void ReadFromStream (StreamReader reader)
		{
			/*
			string peerIp = null;
			double offset = 0;
			double frequency = 0;
			double jitter = 0;
			double stability = 0;
							
			while (reader.Peek() != -1) {
				string line = reader.ReadLine ();
			
				if (line.Trim () == String.Empty)
					continue;

				string name = line.Substring (0, 22).Replace (":", String.Empty).TrimEnd ();
				string value = line.Substring (22).TrimEnd ();
			
				switch (name) {
				case "system peer":
					peerIp = value.Trim ();
					break;				
				case "offset":
					offset = Convert.ToDouble (value.Replace ("s", String.Empty).Trim ());
					break;
				case "frequency":
					frequency = Convert.ToDouble (value.Replace ("ppm", String.Empty).Trim ());
					break;
				case "jitter":
					jitter = Convert.ToDouble (value.Replace ("s", String.Empty).Trim ());
					break;
				case "stability":
					stability = Convert.ToDouble (value.Replace ("ppm", String.Empty).Trim ());
					break;
				}				
			}
			
			IEnumerable<Peer> peerList = peers.Where (p => p.Ip == peerIp);
				
			Peer peer = null;
								
			if (peerList.Count () == 1) {
				peer = peerList.Single ();
			} else if (peerList.Count () == 0) {
				throw new ArgumentOutOfRangeException ("Peer not known in database.");
			} else {
				throw new ArgumentOutOfRangeException ("Invalid number of peers in database.");
			}
			
			HostReading reading = new HostReading (host, peer, bulk, offset, jitter, frequency, stability);
			
			entries.Add (reading);
			*/
		}
	}
}

