using System;
using System.Net;
using System.Xml;
using System.Collections.Generic;
using Ntp.Analyzer.Objects;

namespace Ntp.Analyzer.Import
{
	public class TimeServerImporter
	{
		public TimeServerImporter ()
		{
		}

		public TimeServer ParseTable (string table, int? orgId)
		{
			XmlDocument doc = new XmlDocument ();
			doc.LoadXml (table);
			
			XmlNodeList rows = doc.ChildNodes [0].ChildNodes;
			
			bool firstRow = true;
			
			Dictionary<string, string> entries = new Dictionary<string, string> ();
			
			foreach (XmlNode node in rows) {
				if (firstRow) {
					firstRow = false;
					continue;
				}
				
				entries.Add (
					node.ChildNodes [0].InnerText.Trim (),
					node.ChildNodes [1].InnerText.Trim ()
				);
			}
						
			if (!entries.ContainsKey ("IPv6 Address")) {
				entries.Add ("IPv6 Address", String.Empty);
			}		
			if (!entries.ContainsKey ("HostOrganization")) {
				entries.Add ("HostOrganization", String.Empty);
			}		
			if (!entries.ContainsKey ("AutoKeyURL")) {
				entries.Add ("AutoKeyURL", String.Empty);
			}
			if (!entries.ContainsKey ("SymmetricKeyType")) {
				entries.Add ("SymmetricKeyType", String.Empty);
			}
			if (!entries.ContainsKey ("SymmetricKeyURL")) {
				entries.Add ("SymmetricKeyURL", String.Empty);
			}
					
			string stratusStr = entries ["ServerStratum"];			
			string country = entries ["CountryCode"];
			string name = entries ["Hostname"];
			string ip = entries ["IP Address"];
			string ip6 = entries ["IPv6 Address"];
			string useDnsStr = entries ["UseDNS"];
			string poolMemberStr = entries ["PoolMember"];
			string location = entries ["ServerLocation"];
			string display = entries ["ServerLocation"];
			string org = entries ["HostOrganization"];
			string geo = entries ["GeographicCoordinates"];			
			string server = entries ["ServerSynchronization"];
			string serviceArea = entries ["ServiceArea"];
			string accessPolicy = entries ["AccessPolicy"];
			string accessDetails = entries ["AccessDetails"];
			string notificationStr = entries ["NotificationMessage"];
			string autoKey = entries ["AutoKeyURL"];
			string symKey = entries ["SymmetricKeyType"];
			string symUrl = entries ["SymmetricKeyURL"];						
			string contact = entries ["ServerContact"];
			
			int stratus = 0;

			if (stratusStr == "StratumOne") {
				stratus = 1;
			} else if (stratusStr == "StratumTwo") {
				stratus = 2;
			} else {
				stratus = 19;
			}			

			IPAddress address = null;
			IPAddress.TryParse (ip, out address);
			
			bool? useDns = GetBool (useDnsStr);			
			bool? poolMember = GetBool (poolMemberStr);
			bool? notification = GetBool (notificationStr);
				
			return new TimeServer (
				orgId.Value, orgId, stratus, country, name, address, ip6, useDns, poolMember, location,
				display, org, geo, server, serviceArea, accessDetails, accessPolicy,
				notification, autoKey, symKey, symUrl, contact);
		}

		private bool? GetBool (string boolString)
		{
			string test = boolString.Trim ().ToLower ();
			
			if (test == "yes")
				return true;
			if (test == "no")
				return false;
			if (test == String.Empty)
				return null;
			
			throw new ArgumentOutOfRangeException ("Unknown boolean type.");
		}
	}
}

