using System;
using System.IO;
using System.Net;

namespace Ntp.Analyzer.Import
{
	public class TimeServerLoader
	{
		public TimeServerLoader ()
		{
		}
		
		private const string ntpOrg = "http://support.ntp.org/bin/view/Servers/PublicTimeServer";
		
		private const string serverTagStart = @"<div class=""twikiContentFooter""></div><div class=""twikiForm"">";
		private const string serverTagEnd = @"</div><!-- /twikiForm --></div><!-- /patternContent-->";

		public string ImportServer (int orgId)
		{
			string html = GetOrgHtml (orgId);
			
			int serverTagPos = html.IndexOf (serverTagStart);
			int tableStartPos = html.IndexOf ("<table", serverTagPos);
			int tableEndPos = html.IndexOf (serverTagEnd, serverTagPos);
			
			string table = html.Substring (tableStartPos, tableEndPos - tableStartPos);
			
			return table;
		}
			
		private string GetOrgHtml (int orgId)
		{
			string url = ntpOrg + orgId.ToString ().PadLeft (6, '0');
						
			try {
				WebClient client = new WebClient ();
				client.Headers.Add (
					"user-agent",
					"Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2;)"
				);

				Stream stream = client.OpenRead (url);
				StreamReader reader = new StreamReader (stream);
				
				string html = reader.ReadToEnd ();
			
				stream.Close ();
				reader.Close ();
				
				return html.Replace("<nos>", String.Empty);        
				
			} catch (WebException ex) {
				if (ex.Response is HttpWebResponse) {
					switch (((HttpWebResponse)ex.Response).StatusCode) {
					case HttpStatusCode.NotFound:
						return null;
					default:
						throw ex;
					}
				}
				
				return null;
			}
		}
	}
}

