//
// HostIOStatJob.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System.Linq;
using Ntp.Process;
using Ntp.Analyzer.Log;
using Ntp.Analyzer.Config.Stats;
using Ntp.Analyzer.Data;
using Ntp.Analyzer.Data.Live;
using Ntp.Analyzer.Objects;
using Ntp.Analyzer.Objects.Live;

namespace Ntp.Analyzer.Process.Description
{
    public sealed class HostIOStatJob : JobDescription
    {
        public HostIOStatJob (HostIOStatConfiguration config, LogBase log)
            : base(config, log)
        {
            this.config = config;
        }

        private readonly HostIOStatConfiguration config;

        public override bool SingleThread {
            get { return false; }
        }

        public override string JobType {
            get { return "Host IO stats"; }
        }

        public override int Priority {
            get { return 2; }
        }

        protected override void InternalExecute ()
        {
            Host host = DataFace.Instance.Hosts.SingleOrDefault (h => h.Name == config.ServerName);

            if (host == null) {
                Log.WriteLine ("Hostname not found in database: " + config.ServerName, Severity.Warn);
                return;
            }

            IOStatsLiveMapper liveMapper = new IOStatsLiveMapper (new ServerName (config.ServerName));

            foreach (IOStatsEntry entry in liveMapper) {
                HostIOReading reading = new HostIOReading (host, entry, ReadingBulk.Current);
                DataFace.Instance.HostIOReadings.Save (reading);
            }
        }
    }
}
