//
// Schedule.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.dk>
//
// Copyright (c) 2013 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;

namespace Ntp.Analyzer.Math
{
    public static class Schedule
    {
        public static DateTime CalculateNextRun (DateTime start, int frequency)
        {
            int multiplier = Convert.ToInt32 (System.Math.Truncate ((double)(start.Hour * 60 + start.Minute) / frequency));
            int startMinuttes = multiplier * frequency;

            int hour = (startMinuttes + frequency) / 60;
            int minute = (startMinuttes + frequency) % 60;

            if (hour >= 24) {
                hour -= 24;
                start = start.AddDays (1);
            }

            if (minute >= 60) {
                minute -= 60;
                start.AddHours (1);
            }

            DateTime next = new DateTime (start.Year, start.Month, start.Day, hour, minute, 0);           

            return next;
        }
    }
}
