//
// GraphPageBuilder.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System.Collections.Generic;
using System.IO;
using Ntp.Analyzer.Config.Destination;
using Ntp.Analyzer.Config.Graph;
using Ntp.Analyzer.Config.Page;
using Ntp.Analyzer.Export;
using Ntp.Analyzer.Objects;
using Ntp.Analyzer.Render;
using Ntp.Analyzer.Render.Graph;

namespace Ntp.Analyzer.Page
{
    public sealed class GraphPageBuilder : PageBuilderBase
    {
        public GraphPageBuilder(
            GraphPageConfiguration config,
            NamedObject namedObject,
            string prefix,
            GraphSetConfiguration graphSet,
            GraphBaseConfiguration graph,
            string file)
        {
            this.config = config;
            this.namedObject = namedObject;
            this.prefix = prefix;
            this.graphSet = graphSet;
            this.graph = graph;
            this.file = file;
        }

        private readonly GraphPageConfiguration config;
        private readonly GraphBaseConfiguration graph;
        private readonly GraphSetConfiguration graphSet;
        private readonly NamedObject namedObject;
        private readonly string prefix;
        private readonly string file;
        
        public override IEnumerable<StreamDestination> Destinations
        {
            get { return config.Destinations.Destinations; }
        }

        public string File {
            get { return file; }
        }

        public override Stream Generate()
        {
            BootstrapGrapPageRender page = new BootstrapGrapPageRender(
                config.WebPath,
                namedObject,
                config.Title,
                prefix,
                graphSet,
                graph);

            // Generate HTML
            HtmlRenderer htmlRender = new HtmlRenderer(page);
            string html = htmlRender.Render();

            return ToStream(html);
        }
    }
}
