//
// PageBuilderBase.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Linq;
using Ntp.Analyzer.Export;
using Ntp.Web;
using Ntp.Analyzer.Process;
using Ntp.Analyzer.Servable;

namespace Ntp.Analyzer.Page
{
    public abstract class PageBuilderBase : IStreamGenerator, IServableContent
    {
        public abstract IEnumerable<StreamDestination> Destinations { get; }

        public abstract Stream Generate();

        public virtual string[] Locators {
            get { return Destinations.OfType<WebDestination>().Select(d => d.AbsoluteLocation).ToArray(); }
        }

        public string ContentType {
            get { return "text/html"; }
        }

        public void Execute (Stream input, Stream output)
        {
            Stream result = Generate();
            result.Position = 0;
            result.CopyTo(output);
            result.Close();
            result = null;
        }

        protected Stream ToStream(string text)
        {
            MemoryStream stream = new MemoryStream();

            StreamWriter writer = new StreamWriter(stream, Encoding.UTF8);
            writer.Write(text);
            writer.Flush();

            return stream;
        }
    }
}
