//
// HostPageProcess.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Ntp.Web;
using Ntp.Analyzer.Statistics;
using Ntp.Analyzer.Objects;
using System.IO;
using System.Collections.Generic;
using Ntp.Analyzer.Page;
using Ntp.Analyzer.Config.Navigation;
using Ntp.Analyzer.Config.Page;
using Ntp.Analyzer.Log;

namespace Ntp.Analyzer.Process
{
    public sealed class HostPageProcess : ProcessBase
    {
        public HostPageProcess (MenuConfiguration menu, HostPageConfiguration page, LogBase log)
            : base (page, log)
        {
            this.menu = menu;
            this.page = page;
        }
        
        private readonly MenuConfiguration menu;
        private readonly HostPageConfiguration page;
        
        public IServable[] CreatePages ()
        {
            StatusBuilder builder = new StatusBuilder (
                                                new ServerName (page.ServerName),
                                                new FileInfo (page.ConfigFile));
            builder.Build ();
            
            return new List<IServable> () { 
                new BootstrapHostPageBuilder (menu, page, builder.Entries.ToArray ()),
                new DefaultHostPageBuilder (page, builder.Entries.ToArray ())
            }.ToArray ();
        }

        private PageBuilderBase CreatePageBuilder ()
        {
            StatusBuilder builder = new StatusBuilder (
                                        new ServerName (page.ServerName),
                                        new FileInfo (page.ConfigFile));
            builder.Build ();

            PageBuilderBase pageBuilder;

            if (page.Theme == "bootstrap")
                pageBuilder = new BootstrapHostPageBuilder (menu, page, builder.Entries.ToArray ());
            else
                pageBuilder = new DefaultHostPageBuilder (page, builder.Entries.ToArray ());
                
            return pageBuilder;    
        }

        protected override void InternalExecute ()
        {
            SaveStream (CreatePageBuilder ());
        }
    }
}

