//
// PeerGraphPageProcess.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using Ntp.Web;
using System.Collections.Generic;
using Ntp.Analyzer.Page;
using Ntp.Analyzer.Data;
using Ntp.Analyzer.Objects;
using Ntp.Analyzer.Config.Destination;
using System.Linq;
using Ntp.Analyzer.Config.Graph;
using Ntp.Analyzer.Config.Page;
using Ntp.Analyzer.Log;

namespace Ntp.Analyzer.Process
{
    public sealed class PeerGraphPageProcess : ProcessBase
    {
        public PeerGraphPageProcess (PeerGraphPageConfiguration config, LogBase log)
            : base (config, log)
        {
            this.config = config;
        }
        
        private readonly PeerGraphPageConfiguration config;

        public IServable[] CreatePages ()
        {
            return CreatePageBuilders ().ToArray ();
        }

        private IEnumerable<GraphPageBuilder> CreatePageBuilders ()
        {
            List<GraphPageBuilder> pageBuilders = new List<GraphPageBuilder> ();
        
            Host host = DataFace.Instance.Hosts.Single (h => h.Id == config.HostId);

            foreach (GraphSetConfiguration graphSet in config.GraphSets) {
                foreach (GraphBaseConfiguration graph in graphSet.Graphs) {
                    foreach (NtpConfEntry entry in DataFace.Instance.NtpConfigCache[config.ConfigFile]) {
                        IEnumerable<Peer> peers = DataFace.Instance.Peers.Where (p => p.OrgId == entry.OrgId.Value);

                        if (peers.Count () == 0) {
                            Log.WriteLine ("Peer not found in database: " + entry.Name, Severity.Warn);
                            continue;
                        }

                        Peer peer = peers.Single ();

                        string file = config.GetFileName (host, peer.Server, graphSet, graph);
                        GraphPageBuilder builder = new GraphPageBuilder (config, peer, peer.Server.Name, graphSet, graph, file);
                        
                        pageBuilders.Add (builder);
                    }
                }
            }
            
            return pageBuilders;
        }

        protected override void InternalExecute ()
        {
            IEnumerable<GraphPageBuilder> builders = CreatePageBuilders ();
        
            foreach (GraphPageBuilder builder in builders) {
                SaveStream (builder, builder.File);
            }
        }
    }
}

