//
// ProcessBase.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.IO;
using Ntp.Analyzer.Log;
using System.Collections.Generic;

namespace Ntp.Analyzer.Process
{
    public abstract class ProcessBase
    {
        protected ProcessBase (LogBase log)
        {
            input = new MemoryStream();
            output = new MemoryStream();
            tasks = new List<ITask>();
        }
        
        private readonly LogBase log;
        private readonly Stream input;
        private readonly Stream output;
        private readonly List<ITask> tasks;

        public LogBase Log {
            get { return log; }
        }

        public Stream Input {
            get { return input; }
        }
        
        public Stream Output {
            get { return output; }
        }

        protected List<ITask> Tasks {
            get { return tasks; }
        }
        
        public void Start ()
        {
            foreach(ITask task in tasks)
                task.Execute(input, output);
        }
        
        protected abstract void CreateTasks();
    }
}
