//
// TrafficGraphProcess.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Ntp.Analyzer.Objects;
using Ntp.Analyzer.Data;
using Ntp.Analyzer.Graph;
using Ntp.Analyzer.Config.Graph;
using Ntp.Analyzer.Log;
using System.Linq;

namespace Ntp.Analyzer.Process
{
    public sealed class TrafficGraphProcess : ProcessBase
    {
        public TrafficGraphProcess(TrafficGraphConfiguration config, LogBase log)
            : base(config, log)
        {
            this.config = config;
        }

        private readonly TrafficGraphConfiguration config;

        protected override void InternalExecute()
        {
            Host host;

            try
            {
                host = DataFace.Instance.Hosts.Single(h => h.Name == config.ServerName);
            }
            catch (Exception)
            {
                Log.WriteLine("Hostname not found in database: " + config.ServerName, Severity.Warn);
                return;
            }

            TrafficGraph graph = new TrafficGraph(config, host);
            SaveStream(graph);
        }
    }
}

