//
// BootstrapMenuRender.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Linq;
using System.Text;
using Ntp.Analyzer.Config.Navigation;

namespace Ntp.Analyzer.Render
{
    public sealed class BootstrapMenuRender : HtmlObjectRender
    {
        private readonly MenuConfiguration menu;
        private readonly ILinkable page;

        public BootstrapMenuRender(string webPath, MenuConfiguration menu, ILinkable page)
            : base(webPath)
        {
            this.menu = menu;
            this.page = page;
        }

        public override string RenderHead()
        {
            return String.Empty;
        }

        public override string Render()
        {
            StringBuilder builder = new StringBuilder();

            builder.AppendLine(@"  <div class=""navbar navbar-inverse navbar-fixed-top"">");
            builder.AppendLine(@"    <div class=""container"">");
            builder.AppendLine(@"      <div class=""navbar-header"">");
            builder.AppendLine(@"        <button type=""button"" class=""navbar-toggle"" data-toggle=""collapse"" data-target="".navbar-collapse"">");
            builder.AppendLine(@"          <span class=""icon-bar""></span>");
            builder.AppendLine(@"          <span class=""icon-bar""></span>");
            builder.AppendLine(@"          <span class=""icon-bar""></span>");
            builder.AppendLine(@"        </button>");

            HeadMenuItemConfiguration headItem = menu.MenuItems.
                                                      Single(i => i is HeadMenuItemConfiguration) as HeadMenuItemConfiguration;

            if (headItem != null)
                builder.AppendLine(this.AppendWithWebpath(
                    @"        <a class=""navbar-brand"" href=""{0}{1}"">{2}</a>",
                    headItem.Link, headItem.Caption));

            builder.AppendLine(@"      </div>");
            builder.AppendLine(@"      <div class=""navbar-collapse collapse"">");
            builder.AppendLine(@"        <ul class=""nav navbar-nav"">");

            foreach (MenuItemConfiguration item in menu.MenuItems.Where(i => !(i is HeadMenuItemConfiguration)))
            {
                string active = (item.Page == page) ? @" class=""active""" : String.Empty;

                if (item is LinkMenuItemConfiguration || item is PageMenuItemConfiguration)
                {
                    builder.AppendLine(this.AppendWithWebpath(
                        @"          <li{3}><a href=""{0}{1}"">{2}</a></li>",
                        item.Link, item.Caption, active));
                }
                else if (item is DropdownItemConfiguration)
                {
                    builder.AppendLine(@"          <li class=""dropdown"">");
                    builder.AppendLine(
                        @"            <a href=""#"" class=""dropdown-toggle"" data-toggle=""dropdown"">Peers <b class=""caret""></b></a>");
                    builder.AppendLine(@"            <ul class=""dropdown-menu"">");

                    DropdownItemConfiguration dropdownItem = item as DropdownItemConfiguration;

                    foreach (MenuItemConfiguration subItem in dropdownItem.MenuItems)
                    {
                        if (subItem is LinkMenuItemConfiguration || subItem is PageMenuItemConfiguration)
                        {
                            builder.AppendLine(this.AppendWithWebpath(
                                @"              <li><a href=""{0}{1}"">{2}</a></li>",
                                subItem.Link, subItem.Caption));
                        }
                        else if (subItem is SpacerMenuItemConfiguration)
                        {
                            builder.AppendLine(@"              <li class=""divider""></li>");
                        }
                        else if (subItem is HeaderMenuItemConfiguration)
                        {
                            builder.AppendLine(String.Format(
                                @"              <li class=""dropdown-header"">{0}</li>", subItem.Caption));
                        }
                        else
                        {
                            throw new NotSupportedException("Unknown item type.");
                        }
                    }

                    builder.AppendLine(@"            </ul>");
                }
                else
                {
                    throw new NotSupportedException("Unknown item type.");
                }
            }

            builder.AppendLine(@"          </li>");
            builder.AppendLine(@"        </ul>");
            builder.AppendLine(@"      </div>");
            builder.AppendLine(@"    </div>");
            builder.AppendLine(@"  </div>");

            return builder.ToString();
        }

        public override string RenderFooter()
        {
            return String.Empty;
        }
    }
}