//
// HostTableHtmlRender.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Text;

namespace Ntp.Analyzer.Render.Host
{
    public sealed class DefaultHostTableRender : HtmlObjectRender
    {
        private readonly string[] columns = new[]
            {
                "&nbsp;",
                "Name",
                "st",
                "when",
                "poll",
                "reach",
                "&nbsp;delay",
                "offset",
                "jitter",
                "iso&nbsp;",
                "location"
            };

        public DefaultHostTableRender(string webPath)
            : base(webPath)
        {
        }

        public override string RenderHead()
        {
            StringBuilder builder = new StringBuilder();

            builder.Append("<table><tr>");

            foreach (string column in columns)
            {
                builder.Append("<th>");
                builder.Append(column);
                builder.Append("</th>");
            }

            builder.AppendLine("</tr>");
            builder.Append(MakeSpacer());

            return builder.ToString();
        }

        public override string Render()
        {
            return String.Empty;
        }

        public override string RenderFooter()
        {
            StringBuilder builder = new StringBuilder();

            builder.Append(MakeSpacer());
            builder.Append("<tr>");

            foreach (string column in columns)
            {
                builder.Append(@"<td class=""but"">&nbsp;</td>");
            }

            builder.AppendLine("</tr>");
            builder.AppendLine("</table>");

            return builder.ToString();
        }

        private string MakeSpacer()
        {
            StringBuilder builder = new StringBuilder();

            builder.Append("<tr>");

            foreach (string column in columns)
            {
                builder.Append(@"<td class=""spc"">&nbsp;</td>");
            }

            builder.AppendLine("</tr>");

            return builder.ToString();
        }
    }
}