//
// BootstrapSummeryGraphRender.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Ntp.Analyzer.Config.Destination;
using Ntp.Analyzer.Config.Graph;
using Ntp.Analyzer.Config.Page;
using Ntp.Analyzer.Data;
using Ntp.Analyzer.Objects;

namespace Ntp.Analyzer.Render.Summery
{
    public sealed class BootstrapSummeryGraphRender : HtmlObjectRender
    {
        private readonly List<GraphSetConfiguration> graphs;
        private readonly PeerSummeryPageConfiguration page;

        public BootstrapSummeryGraphRender(
            string webPath,
            PeerSummeryPageConfiguration page,
            IEnumerable<GraphSetConfiguration> graphs)
            : base(webPath)
        {
            this.page = page;
            this.graphs = new List<GraphSetConfiguration>(graphs);
        }

        public override string RenderHead()
        {
            StringBuilder builder = new StringBuilder();

            builder.AppendLine(@"  <div class=""container theme-graph"">");
            builder.AppendLine(@"    <div class=""panel-group"" id=""accordion"">");

            return builder.ToString();
        }

        public override string Render()
        {
            StringBuilder builder = new StringBuilder();
            int count = 1;

            // TODO: Add host graph

            foreach (GraphSetConfiguration graphSet in graphs)
            {
                string open = (count == 1) ? " in" : String.Empty;

                builder.AppendLine(@"      <div class=""panel panel-default"">");
                builder.AppendLine(@"        <div class=""panel-heading"">");
                builder.AppendLine(@"          <h4 class=""panel-title"">");

                // Include panel counter
                builder.Append(@"            <a class=""accordion-toggle"" data-toggle=""collapse"" ");
                builder.Append(@"data-parent=""#accordion"" href=""#collapse");
                builder.Append(count);
                builder.AppendLine(@""">");

                builder.AppendLine(@"              " + graphSet.Title);
                builder.AppendLine(@"            </a>");
                builder.AppendLine(@"          </h4>");
                builder.AppendLine(@"        </div>");

                // Include panel counter
                builder.Append(@"        <div id=""collapse");
                builder.Append(count);
                builder.AppendFormat(@""" class=""panel-collapse collapse{0}"">", open);
                builder.AppendLine();
                builder.AppendLine(@"          <div class=""panel-body"">");

                foreach (NtpConfEntry entry in DataFace.Instance.NtpConfigCache[page.ConfigFile])
                {
                    IEnumerable<Objects.Peer> peers = DataFace.Instance.Peers.Where(p => p.OrgId == entry.OrgId.Value);

                    if (peers.Count() == 0)
                    {
                        throw new ApplicationException("Peer not found in database: " + entry.Name);
                    }

                    Objects.Peer peer = peers.Single();

                    // TODO: Add links for images.
                    foreach (GraphBaseConfiguration graph in graphSet.Graphs)
                    {
                        builder.Append(@"            <div class=""container theme-graph2"">");
                        builder.Append(@"<a href=""");
                        builder.Append(page.GetPeerLink(peer.OrgId));
                        builder.Append(@""">");
                        builder.Append(@"<img class=""img-responsive"" src=""");
                        builder.Append(graph.GetLink(graphSet, peer.Server.Name));
                        builder.Append(@""" alt=""");
                        builder.Append(graph.GetAltName(graphSet, peer.Server.Name));
                        builder.Append(@""">");
                        builder.AppendLine(@"</a></div>");
                    }
                }

                builder.AppendLine(@"          </div>");
                builder.AppendLine(@"        </div>");
                builder.AppendLine(@"      </div>");

                count++;
            }

            return builder.ToString();
        }

        public override string RenderFooter()
        {
            StringBuilder builder = new StringBuilder();

            builder.AppendLine(@"    </div>");
            builder.AppendLine(@"  </div>");

            return builder.ToString();
        }
    }
}