//
// PeerSummeryGraphHtmlRender.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Ntp.Analyzer.Config.Destination;
using Ntp.Analyzer.Config.Graph;
using Ntp.Analyzer.Config.Page;
using Ntp.Analyzer.Data;
using Ntp.Analyzer.Objects;

namespace Ntp.Analyzer.Render.Summery
{
    public sealed class DefaultPeerSummeryGraphRender : HtmlObjectRender
    {
        private readonly List<GraphSetConfiguration> graphs;
        private readonly PeerSummeryPageConfiguration page;

        public DefaultPeerSummeryGraphRender(
            PeerSummeryPageConfiguration page,
            IEnumerable<GraphSetConfiguration> graphs)
            : base(page.WebPath)
        {
            this.page = page;
            this.graphs = new List<GraphSetConfiguration>(graphs);
        }

        public override string RenderHead()
        {
            return String.Empty;
        }

        public override string Render()
        {
            StringBuilder builder = new StringBuilder();

            // TODO: Add host graph

            foreach (NtpConfEntry entry in DataFace.Instance.NtpConfigCache[page.ConfigFile])
            {
                IEnumerable<Objects.Peer> peers = DataFace.Instance.Peers.Where(p => p.OrgId == entry.OrgId.Value);

                if (peers.Count() == 0)
                {
                    throw new ApplicationException("Peer not found in database: " + entry.Name);
                }

                Objects.Peer peer = peers.Single();

                foreach (GraphSetConfiguration graphSet in graphs)
                {
                    foreach (GraphBaseConfiguration graph in graphSet.Graphs)
                    {
                        builder.Append(@"<a href=""");
                        builder.Append(page.GetPeerLink(peer.OrgId));
                        builder.Append(@""">");
                        builder.Append(@"<img src=""");
                        builder.Append(graph.GetLink(graphSet, peer.Server.Name));
                        builder.Append(@""" alt=""");
                        builder.Append(graph.GetAltName(graphSet, peer.Server.Name));
                        builder.Append(@""">");
                        builder.AppendLine(@"</a>");
                    }
                }
            }

            return builder.ToString();
        }

        public override string RenderFooter()
        {
            return String.Empty;
        }
    }
}