//
// StaticServable.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.IO;

namespace Ntp.Analyzer.Servable
{
    public sealed class StaticServable : ServableBase
    {
        public StaticServable (string domain, string webPath, string filePath, string file)
            : base(domain, ContentTypeFromFile(file))
        {
            this.webPath = webPath;
            this.filePath = filePath;
            this.file = file;
        }

        private readonly string webPath;
        private readonly string filePath;
        private readonly string file;

        public string File {
            get { return file; }
        }

        public Stream Generate ()
        {
            StreamReader reader = new StreamReader (filePath + file);
            return reader.BaseStream;
        }

        public string[] Locators {
            get { return new String[] { Domain + "@" + webPath + file }; }
        }

        private string ContentTypeFromFile ()
        {
                int i = file.LastIndexOf ('.');
                string type = file.Substring (i + 1);
            
                switch (type) {
                case "html":
                    return "text/html";
                case "htm":
                    return "text/html";
                case "css":
                    return "text/css";
                case "js":
                    return "text/javascript";
                case "jpg":
                    return "image/jpeg";
                case "png":
                    return "image/png";
                case "svg":
                    return "image/svg+xml";
                case "eot":
                    return "application/vnd.ms-fontobject";
                case "ttf":
                    return "application/x-font-ttf";
                case "woff":
                    return "application/x-font-woff";
                default:
                    return "text/plain";
                }
        }

    }
}
