//
// ConfigurationBlock.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2014 Carsten Sonne Larsen
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections;
using System.Collections.Generic;

namespace Ntp.Config
{
    public class ConfigurationBlock : IEnumerable<String>
    {
        private readonly int indentLevel;
        private readonly int index;
        private readonly string[] lines;

        public ConfigurationBlock(string[] lines)
            : this(0, lines, -1)
        {
        }

        internal ConfigurationBlock(int index, string[] lines, int indentLevel)
        {
            this.index = index;
            this.lines = lines;
            this.indentLevel = indentLevel;
        }

        public string[] Lines
        {
            get { return lines; }
        }

        public int IndentLevel
        {
            get { return indentLevel; }
        }

        public int Offset
        {
            get { return index + lines.Length; }
        }

        public IEnumerator<string> GetEnumerator()
        {
            return new List<String>(lines).GetEnumerator();
        }

        IEnumerator IEnumerable.GetEnumerator()
        {
            return lines.GetEnumerator();
        }
    }
}
