//
// BinaryRequest.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2013 
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Net;
using System.Net.Sockets;
using System.Text;
using System.IO;

namespace Ntp.Monitor.Client
{
    public sealed class BinaryRequest : Request
    {
        public BinaryRequest (IPAddress ip, int port)
            : base(ip, port)
        {
        }

        public byte[] Send (string command)
        {
            Socket clientSocket = new Socket (
                AddressFamily.InterNetwork,
                SocketType.Stream,
                ProtocolType.Tcp);

            clientSocket.Connect (Server);

            byte[] sendBuffer = Encoding.ASCII.GetBytes (command);

            SocketError error;
            clientSocket.Send (sendBuffer, 0, sendBuffer.Length, SocketFlags.None, out error);

            const int size = 4096;

            MemoryStream stream = new MemoryStream (size);
            byte[] buffer = new byte[size];

            int length;

            do {
                length = clientSocket.Receive (buffer, 0, size, SocketFlags.None, out error);
                stream.Write (buffer, 0, length);
            } while (length > 0);

            clientSocket.Shutdown (SocketShutdown.Both);
            clientSocket.Close ();

            return stream.ToArray ();
        }
    }
}
