//
// Request.cs
//
// Author:
//       Carsten Sonne Larsen <cs@innolan.net>
//
// Copyright (c) 2013 
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Net.Sockets;
using System.Text;

namespace Ntp.Monitor.Server
{
    internal class Request
    {
        internal byte[] Buffer;
        internal Socket Socket;

        internal Request(int size, Socket sock)
        {
            Buffer = new byte[size];
            Socket = sock;
        }

        private string Content
        {
            get { return Encoding.ASCII.GetString(Buffer); }
        }

        internal string Command
        {
            get { return Content != null ? Content.Split(' ')[0] : String.Empty; }
        }

        internal string[] Arguments
        {
            get
            {
                if (Content == null)
                    return new String[0];

                List<String> args = new List<String>(Content.Split(' '));
                args.RemoveAt(0);

                return args.ToArray();
            }
        }

        internal void ReSize(int size)
        {
            byte[] newBuffer = new byte[size];

            for (int i = 0; i < size; i++)
                newBuffer[i] = Buffer[i];

            Buffer = newBuffer;
        }
    }
}