-- CREATE DATABASE ntpa; -- CHARACTER SET utf8 COLLATE utf8_bin;
USE ntpa;

DROP USER 'ntpau'@'localhost';

CREATE USER 'ntpau'@'localhost' IDENTIFIED BY 'xxxx';
GRANT ALL PRIVILEGES ON ntpa.* TO 'ntpau'@'localhost';
FLUSH PRIVILEGES;

DROP TABLE hostReading;
DROP TABLE peerReading;
DROP TABLE host;
DROP TABLE peer;

CREATE TABLE host (
	id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	name VARCHAR(30) NOT NULL,
	ip VARCHAR(15) NOT NULL,
	orgId INT
) ENGINE=INNODB;

CREATE TABLE peer (
	id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	name VARCHAR(30) NULL,
	ip VARCHAR(15) NULL,
	orgId INT
) ENGINE=INNODB;

CREATE TABLE peerReading (
	id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	time  TIMESTAMP NOT NULL,
	hostId INT NOT NULL,
	peerId INT NOT NULL,
	last INT NOT NULL,
	reach INT NOT NULL,
	delay DOUBLE NOT NULL,
	offset DOUBLE NOT NULL,
	jitter DOUBLE NOT NULL,
	FOREIGN KEY (hostId) REFERENCES host(id),
	FOREIGN KEY (peerId) REFERENCES peer(id)
) ENGINE=INNODB;

CREATE TABLE hostReading (
	id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	time  TIMESTAMP NOT NULL,
	hostId INT NOT NULL,
	peerId INT NOT NULL,
	offset DOUBLE NOT NULL,
	jitter DOUBLE NOT NULL,
	frequency DOUBLE NOT NULL,
	stability DOUBLE NOT NULL,
	FOREIGN KEY (hostId) REFERENCES host(id),
	FOREIGN KEY (peerId) REFERENCES peer(id)
) ENGINE=INNODB;

-- /usr/sbin/ntpdc -c loopinfo -c sysinfo innolan.dk
-- offset:               0.002156 s
-- frequency:            -3.236 ppm
-- poll adjust:          -21
-- watchdog timer:       341 s
-- system peer:          ntp1.gbg.netnod.se
-- system peer mode:     client
-- leap indicator:       00
-- stratum:              2
-- precision:            -19
-- root distance:        0.02443 s
-- root dispersion:      0.02937 s
-- reference ID:         [192.36.133.17]
-- reference time:       d57ad9b4.ed0799db  Sun, Jun 30 2013 18:22:12.925
-- system flags:         auth monitor ntp kernel stats 
-- jitter:               0.000290 s
-- stability:            0.000 ppm
-- broadcastdelay:       0.000000 s
-- authdelay:            0.000050 s

CREATE TABLE timeServer (
	id INT NOT NULL PRIMARY KEY,
	stratum INT NOT NULL,
	countryCode CHAR(7) NOT NULL,
	hostName VARCHAR(50) NOT NULL,
	ip VARCHAR(15) NULL,
	ip6 VARCHAR(30) NULL,
	useDns BIT(1) NULL,
	poolMember BIT(1) NULL,
	location VARCHAR(100) NULL,
	displayLocation VARCHAR(60) NOT NULL DEFAULT "Unknown",
	organization VARCHAR(50) NULL,
	coordinates VARCHAR(50) NULL,
	synchronization VARCHAR(255) NULL,
	serviceArea VARCHAR(100) NULL,
	accessPolicy VARCHAR(255) NULL,
	accessDetails VARCHAR(512) NULL,
	notification BIT(1) NULL,
	autoKeyUrl VARCHAR(255) NULL,
	symmetricKeyType VARCHAR(100) NULL,
	symmetricKeyURL VARCHAR(100) NULL,
	serverContact VARCHAR(255) NULL,
	updated TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP(),
	providerPage VARCHAR(100) NULL,
	providerUrl VARCHAR(255) NULL
) ENGINE=INNODB;

CREATE TABLE ntpPacket (
	id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	time  TIMESTAMP NOT NULL,
	sourceIp VARCHAR(15) NOT NULL,
	sourcePort VARCHAR(5) NOT NULL,
	destinationIp VARCHAR(15) NOT NULL,
	destinationPort VARCHAR(5) NOT NULL,
	type int NULL,
	strat int NULL,
	poll int NULL
) ENGINE=INNODB;

CREATE TABLE hostNtpPacket (
	id INT NOT NULL PRIMARY KEY,
	hostId INT NOT NULL,
	peerId INT NOT NULL,
	FOREIGN KEY (id) REFERENCES ntpPacket(id),
	FOREIGN KEY (hostId) REFERENCES host(id),
	FOREIGN KEY (peerId) REFERENCES peer(id)
) ENGINE=INNODB;

CREATE TABLE sourcePeer (
	id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	ip VARCHAR(15) NULL,
	peerId INT NULL
) ENGINE=INNODB;

CREATE TABLE peerNtpPacket (
	id INT NOT NULL PRIMARY KEY,
	hostId INT NOT NULL,
	sourcePeerId INT NOT NULL,
	FOREIGN KEY (id) REFERENCES ntpPacket(id),
	FOREIGN KEY (hostId) REFERENCES host(id),
	FOREIGN KEY (sourcePeerId) REFERENCES sourcePeer(id)
) ENGINE=INNODB;

COMMIT;